@@ -23,10 +23,9 @@ import os
 from rasterio.io import MemoryFile
 from requests_toolbelt import MultipartEncoder
 import warnings
-import xmltodict
 
 
-__version__ = '1.1.36'
+__version__ = '1.1.39'
 url = 'https://api.ellipsis-drive.com/v1'
 #url = 'https://dev.api.ellipsis-earth.com/v2'
 s = requests.Session()
@@ -217,6 +216,7 @@ def getBounds(projectId, timestamp = None, token = None ):
         raise ValueError(r.text)
     r = r.json()
     r['id'] = 0
+    r['properties'] = {}
     r  = gpd.GeoDataFrame.from_features([r])
     r = r.unary_union
     return(r)
@@ -337,10 +337,12 @@ def geometryDelete(shapeId, geometryIds, token, revert= False):
 
 def geometryEdit(shapeId, geometryIds, features, token):
     features = features.copy()
-    del features['id']
-    del features['user']
-    del features['creationDate']
-    del features['layer']
+    if 'id' in features.columns:
+        del features['id']
+    if 'userId' in features.columns:
+        del features['userId']
+    if 'layer' in features.columns:
+        del features['layer']
 
 
     mapId = shapeId
@@ -637,21 +639,17 @@ def rasterRaw(mapId, timestamp, xMin= None,xMax= None,yMin=None, yMax=None, boun
         if str(type(width)) == str(type(None)) or str(type(height)) == str(type(None)):
             raise ValueError('if downsample is true, width and height are required')
 
-        timestamps = metadata(mapId, token)['timestamps']
 
-        r = s.get(url + '/wms/raw/' + mapId + '?SERVICE=WMS&REQUEST=GetCapabilities' + token_inurl)                
-        d = xmltodict.parse(r.text)
-        layers = {}
-        for layer in d['Capabilities']['Capability']['Layer']:
-            layers[layer['Title']] = layer['Name']
-                
+        bbox = {'xMin':xMin, 'xMax':xMax, 'yMin':yMin , 'yMax':yMax}
+        body = {'mapId':mapId, 'timestamp' : timestamp, 'mapId':mapId, 'bounds':bbox, 'width':width, 'height':height}
+
+        if str(type(token)) == str(type(None)):
+            r = s.post(url + '/raster/raw',
+                         json = body )        
+        else:
+            r = s.post(url + '/raster/raw', headers = {"Authorization":token},
+                         json = body )
 
-        timestampDate = next(item['dateTo'] for item in timestamps if item["timestamp"] == timestamp)
-        timestampDate = str(timestampDate).split('T')[0]
-        layerId = layers[timestampDate + '_' + str(timestamp)]
-        w = int(width)
-        h = int(height)
-        r = s.get(url + '/wms/raw/' + mapId + '?SERVICE=WMS&VERSION=1.3.0&REQUEST=GetMap&BBOX=' + str(yMinWeb) + ',' + str(xMinWeb) + ',' + str(yMaxWeb) + ',' + str(xMaxWeb) + '&CRS=EPSG:3857&WIDTH=' + str(w) + '&HEIGHT=' + str(h) + '&LAYERS=' + layerId + '&STYLES=&FORMAT=image/tiff&DPI=96&MAP_RESOLUTION=96&FORMAT_OPTIONS=dpi:96&TRANSPARENT=TRUE' + token_inurl)
 
         if int(str(r).split('[')[1].split(']')[0]) != 200:
                 raise ValueError(r.text)
@@ -659,8 +657,7 @@ def rasterRaw(mapId, timestamp, xMin= None,xMax= None,yMin=None, yMax=None, boun
                  with MemoryFile(r.content) as memfile:
                      with memfile.open() as dataset:
                          r_total = dataset.read()
-        r_total = np.transpose(r, (1,2,0) )
-
+        r_total = np.transpose(r_total, (1,2,0) )
 
     else:
             bands = metadata(mapId)['bands']
@@ -1003,14 +1000,26 @@ def seriesAggregated(shapeId, geometryIds, aggregation = 'mean',  dateFrom = Non
 
     
 ################################################up and downloads
-def addTimestamp(mapId, startDate, endDate, token, bounds=None):
-    startDate = startDate.strftime('%Y-%m-%d')
-    endDate = endDate.strftime('%Y-%m-%d')
-    
-    
+def addTimestamp(mapId, startDate, token, endDate = None, bounds=None):
+    if str(type(endDate)) == str(type(None)):
+        endDate = startDate
+
+    if str(type(startDate)) != str(type('hoi')):
+        startDate = startDate.strftime('%Y-%m-%d')    
+        endDate = endDate.strftime('%Y-%m-%d')
+
+    toAdd = {'dateFrom':startDate, 'dateTo':endDate}
+
+    if str(type(bounds)) != str(type(None)):
+        boundary = gpd.GeoSeries([bounds]).__geo_interface__['features'][0]
+        boundary = boundary['geometry']
+        toAdd['bounds'] = boundary        
+
+    body = {"mapId":  mapId, "toAdd":[toAdd]}    
+        
     
     r = s.post(url + '/settings/projects/reschedule', headers = {"Authorization":token},
-                 json = {"mapId":  mapId, "toAdd":[{'startDate':startDate, 'endDate':endDate}]})
+                 json = body)
 
     if int(str(r).split('[')[1].split(']')[0]) != 200:
         raise ValueError(r.text)
@@ -1057,7 +1066,7 @@ def uploadRasterFile(mapId, timestampId, file, token, fileFormat = 'tif', epsg =
             raise ValueError( file + ' not found')
     
     conn_file = open(file, 'rb')
-    payload = MultipartEncoder({'upload': (fileName, conn_file, 'application/octet-stream'), 'captureId': timestampId, 'format':fileFormat, 'fileName':fileName})
+    payload = MultipartEncoder({'upload': (fileName, conn_file, 'application/octet-stream'), 'timestampId': timestampId, 'mapId':mapId, 'format':fileFormat, 'fileName':fileName})
     
     if str(type(epsg)) != str(type(None)):
         payload['epsg'] = epsg
@@ -1249,10 +1258,9 @@ def addBand(name, token):
 
     
     
-def newMap(name,  token, bands, dataType = 'float32' ):
+def newMap(name,  token):
 
-
-    body = {'name':name, 'bands':bands, 'dataType':dataType}
+    body = {'name':name}
 
     r = s.post(url + '/settings/projects/newMap', headers = {"Authorization":token},
                      json = body)
@@ -1475,8 +1483,8 @@ def cover(bounds, w):
     coords.crs = {'init': 'epsg:4326'}
 
     return(coords)
-     
-     
+    
+
     
 def loadingBar(count,total):
     percent = float(count)/float(total)*100
